@@ -4,5 +4,6 @@ from whatlies.transformers.noise import Noise
 from whatlies.transformers.addrandom import AddRandom
 from whatlies.transformers.tsne import Tsne
 from whatlies.transformers.opentsne import OpenTsne
+from whatlies.transformers.ivis import Ivis
 
-__all__ = ["Pca", "Umap", "Noise", "AddRandom", "Tsne", "OpenTsne"]
+__all__ = ["Pca", "Umap", "Noise", "AddRandom", "Tsne", "OpenTsne", "Ivis"]
